import sys
import os



#log.i info级别 普通打印
def i(*args):
    print(*args)

#log.w warning级别 蓝色加强
def w(text):
    #FF00
    print('<span style="color:#080"><b>%s</b></span>' % text)

#log.e error级别 红色加强提示
def e(text):
    print('<span style="color:#0A0"><b>%s</b></span>' %text)

#data格式：
#
#
def add_2_tensorboard(data, dir=None):
    if dir == None:
        dir = os.getcwd()
    else:
        if not os.path.exists(dir):
            os.makedirs(dir)

# def



"""Tests for the flatten observation wrapper."""
from flask import Flask, request
import json
import ai_hub.globalvar as gl
import ai_hub.log

app = Flask("tccapi")


@app.route("/tccapi", methods=['GET', 'POST'])
def tccapi():
    ret = ""
    if request.method== 'POST':
        data = request.get_data()
        print("data: ", data)

        # inferserver
        #myinserver = gl.get_value("myinserver")
        inferserver = gl.get_value("inferserver")
        #print(inferserver)

        data_pred = inferserver.pre_process(data)
        print("pred_data: ",data_pred)
        ret = inferserver.pridect(data_pred)
        ret = inferserver.post_process(ret)
        if not isinstance(ret, str):
            ret = str(ret)
        log.i("return: ", ret)
    else:
        log.e("please use post request.such as ：curl localhost:8080/tccapi -X POST -d \'{\"img\"/:2}\'")
    return ret


class inferServer():
    def __init__(self, model):
        self.model = model
        print("init_Server")
        gl._init()
        # gl.set_value("inferModel", model)
        gl.set_value("inferserver", self)


    def pre_process(self, data):
        return data

    def post_process(self, data):
        return data

    def pridect(self, data):
        data = self.model(data)
        return data

    def run(self, ip="127.0.0.1", port=8080, debuge=False):
        app.run(ip, port, debuge)


if __name__ == '__main__':
    myserver = inferServer("")
    myserver.run()




import requests

class notice:
    def __init__(self, openid):
        self.openid = openid

    def sendmsg(self, msg):
        if not isinstance(msg,str):
            msg = str(msg)
        if len(msg) >1024:
            msg = msg[:1024]

        url = "http://35.194.206.106/notice"
        data = {"openid":self.openid,"msg":msg}
        print(data)
        res = requests.post(url=url,params=data)
        print(res.text)
        
    def sendpic(self, pic):
        
        print("send pic.")
        
    def sendplot(self, plot):
        
        print("send plot.")

    def setopenid(self, openid):
        self.openid = openid



from inferServer import inferServer
#import ai_hub.globalvar as gl
import json
import ai_hub.log

class myserver(inferServer):
    def __init__(self,model):
        super().__init__(model)
        log.i("init_myserver")

    def pre_process(self, data):
        log.i("my_pre_process.")
        #json process
        json_data = json.loads(data.decode('utf-8'))
        img = json_data.get("img")
        log.i("data: ", img)
        return img

    #pridict default run as follow：
    # def predict(self, data):
    #     ret = self.model(data)
    #     return ret

    def post_process(self, data):
        return data



if __name__ == '__main__':
    mymodel = lambda x: x * 2
    myserver = myserver(mymodel)
    #run your server, defult ip=localhost port=8080 debuge=false
    myserver.run(debuge=True) #myserver.run("127.0.0.1", 1234)
